@@ -83,13 +83,14 @@ ln -s "${bprefix}/system.h" aqbanking5/aqbanking/system.h
 ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_jobqueue.h" aqbanking5/aqbanking
 ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_accountqueue.h" aqbanking5/aqbanking
 ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_userqueue.h" aqbanking5/aqbanking
+ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_queue.h" aqbanking5/aqbanking
 
 # symlink all headers from src/lib/aqbankingpp
 mkdir -p aqbanking5/aqbankingpp
 symlinkFolder "src/libs/aqbankingpp" "aqbanking5/aqbankingpp"
 
 # symlink all headers from src/plugins/backends/
-dirlist='aqhbci aqofxconnect aqpaypal'  # list might be empty
+dirlist='aqhbci aqnone aqofxconnect aqebics aqpaypal'  # list might be empty
 for backend in ${dirlist} ; do
   mkdir -p aqbanking5/${backend}
   if [ -d "src/plugins/backends/${backend}/plugin" ] ; then
